==> banking-branch_14.8.0.0.0-Plus1.zip: banking-branch_14.8.0.0.0-Plus1_20250419/content/banking-branch/14.8.0.0.0/intgu/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-06672D4F-A336-403A-A15E-9971E13B69B0"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Integration of FLEXCUBE Universal Banking",
                    "href":"integration-flexcube-universal-banking.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Maintenance for FLEXCUBE Universal Banking",
                            "href":"maintenance-flexcube-universal-banking.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.1.1 </span> Maintain Upload Source",
                                    "href":"maintain-upload-source.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.2 </span> Maintain Upload Source Preferences",
                                    "href":"maintain-upload-source-preferences.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.3 </span> Maintain External System",
                                    "href":"maintain-external-system.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.4 </span> Maintain External System Functions",
                                    "href":"maintain-external-system-functions.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.5 </span> Maintain Gateway Amendment",
                                    "href":"maintain-gateway-amendment.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.6 </span> Maintain Customer",
                                    "href":"maintain-customer.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.7 </span> Relationship Pricing Integration",
                                    "href":"relationship-pricing-integration.html",
                                    "topics":[
                                        {
                                            "title":"<span class=\"secnum\">1.1.7.1 </span> Maintain External Price Components of Relationship Pricing",
                                            "href":"maintain-external-price-components-relationship-pricing.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.1.7.2 </span> Maintain External Data Elements of Relationship Pricing",
                                            "href":"maintain-external-data-elements-relationship-pricing.html"
                                        }
                                    ]
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">1.2 </span> Maintenance for Oracle Banking Branch",
                            "href":"maintenance-oracle-banking-branch1.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.2.1 </span> Maintenance Using Oracle Banking Routing Hub",
                                    "href":"maintenance-using-oracle-banking-routing-hub.html",
                                    "topics":[
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.1 </span> Configure Oracle Banking Branch",
                                            "href":"configure-oracle-banking-branch.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.2 </span> Configure Teller Transactions",
                                            "href":"configure-teller-transactions.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.3 </span> Configure Relationship Pricing",
                                            "href":"configure-relationship-pricing.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.4 </span> Configure Account Services",
                                            "href":"configure-account-services.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.5 </span> Configure CASA 360",
                                            "href":"configure-casa-360.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.6 </span> Configure Deposit Services",
                                            "href":"configure-deposit-services.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.7 </span> Configure Loan Services",
                                            "href":"configure-loan-services.html"
                                        }
                                    ]
                                },
                                {
                                    "title":"<span class=\"secnum\">1.2.2 </span> Direct Access",
                                    "href":"direct-access.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.2.3 </span> Relationship Pricing Integration",
                                    "href":"relationship-pricing-integration-01.html",
                                    "topics":[
                                        {
                                            "title":"<span class=\"secnum\">1.2.3.1 </span> Maintain Pricing Source System",
                                            "href":"maintain-pricing-source-system.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.3.2 </span> Maintain Charge Definition",
                                            "href":"maintain-charge-definition.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.3.3 </span> Charge Decision Maintenance",
                                            "href":"charge-decision-maintenance.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.3.4 </span> Transaction Charge Computation",
                                            "href":"transaction-charge-computation.html"
                                        }
                                    ]
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">1.3 </span> Maintenance for Core Replication",
                            "href":"maintenance-core-replication.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.3.1 </span> Add Service Consumers",
                                    "href":"add-service-consumers.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.3.2 </span> Maintain External Services",
                                    "href":"maintain-external-services.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.3.3 </span> Maintain Upload Source Code",
                                    "href":"maintain-upload-source-code.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Integration of Oracle Banking Payments",
                    "href":"integration-oracle-banking-payments.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">2.1 </span> Maintenance for Oracle Banking Branch",
                            "href":"maintenance-oracle-banking-branch.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">2.1.1 </span> Create Entity",
                                    "href":"create-entity.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">2.2 </span> Maintenance for Oracle Banking Payments",
                            "href":"maintenance-oracle-banking-payments.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">2.2.1 </span> Maintain Source Details and Source Network Preferences",
                                    "href":"maintain-source-details-and-source-network-preferences.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">2.2.2 </span> Maintain External Notification and Queue Connection Profile",
                                    "href":"maintain-external-notification-and-queue-connection-profile.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Integration of Oracle Banking Virtual Account Management",
                    "href":"integration-oracle-banking-virtual-account-management.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">3.1 </span> Configurations for Oracle Banking Branch",
                            "href":"configurations-oracle-banking-branch.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.2 </span> Maintenance for Oracle Banking Virtual Account Management",
                            "href":"maintenance-oracle-banking-virtual-account-management.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">3.2.1 </span> Maintain Entry in Common Core",
                                    "href":"maintain-entry-common-core.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">3.2.2 </span> Create User and Assign Role",
                                    "href":"create-user-and-assign-role.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">3.2.3 </span> Create Upload Source",
                                    "href":"create-upload-source.html"
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ]
});

==> banking-branch_14.8.1.0.0-Plus1.zip: banking-branch_14.8.1.0.0-Plus1_20251105/content/banking-branch/14.8.1.0.0/intgu/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface1.html#GUID-06672D4F-A336-403A-A15E-9971E13B69B0"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Integration of FLEXCUBE Universal Banking",
                    "href":"integration-flexcube-universal-banking.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Maintenance for FLEXCUBE Universal Banking",
                            "href":"maintenance-flexcube-universal-banking.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.1.1 </span> Maintain Upload Source",
                                    "href":"maintain-upload-source.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.2 </span> Maintain Upload Source Preferences",
                                    "href":"maintain-upload-source-preferences.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.3 </span> Maintain External System",
                                    "href":"maintain-external-system.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.4 </span> Maintain External System Functions",
                                    "href":"maintain-external-system-functions.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.5 </span> Maintain Gateway Amendment",
                                    "href":"maintain-gateway-amendment.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.6 </span> Maintain Customer",
                                    "href":"maintain-customer.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.7 </span> Relationship Pricing Integration",
                                    "href":"relationship-pricing-integration.html",
                                    "topics":[
                                        {
                                            "title":"<span class=\"secnum\">1.1.7.1 </span> Maintain External Price Components of Relationship Pricing",
                                            "href":"maintain-external-price-components-relationship-pricing.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.1.7.2 </span> Maintain External Data Elements of Relationship Pricing",
                                            "href":"maintain-external-data-elements-relationship-pricing.html"
                                        }
                                    ]
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">1.2 </span> Maintenance for Oracle Banking Branch",
                            "href":"maintenance-oracle-banking-branch.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.2.1 </span> Maintenance Using Oracle Banking Routing Hub",
                                    "href":"maintenance-using-oracle-banking-routing-hub.html",
                                    "topics":[
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.1 </span> Configure Oracle Banking Branch",
                                            "href":"configure-oracle-banking-branch.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.2 </span> Configure Teller Transactions",
                                            "href":"configure-teller-transactions.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.3 </span> Configure Relationship Pricing",
                                            "href":"configure-relationship-pricing.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.4 </span> Configure Account Services",
                                            "href":"configure-account-services.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.5 </span> Configure CASA 360",
                                            "href":"configure-casa-360.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.6 </span> Configure Deposit Services",
                                            "href":"configure-deposit-services.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.1.7 </span> Configure Loan Services",
                                            "href":"configure-loan-services.html"
                                        }
                                    ]
                                },
                                {
                                    "title":"<span class=\"secnum\">1.2.2 </span> Direct Access",
                                    "href":"direct-access.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.2.3 </span> Relationship Pricing Integration",
                                    "href":"relationship-pricing-integration.html",
                                    "topics":[
                                        {
                                            "title":"<span class=\"secnum\">1.2.3.1 </span> Maintain Pricing Source System",
                                            "href":"maintain-pricing-source-system.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.3.2 </span> Maintain Charge Definition",
                                            "href":"maintain-charge-definition.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.3.3 </span> Charge Decision Maintenance",
                                            "href":"charge-decision-maintenance.html"
                                        },
                                        {
                                            "title":"<span class=\"secnum\">1.2.3.4 </span> Transaction Charge Computation",
                                            "href":"transaction-charge-computation.html"
                                        }
                                    ]
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">1.3 </span> Maintenance for Core Replication",
                            "href":"maintenance-core-replication.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.3.1 </span> Add Service Consumers",
                                    "href":"add-service-consumers.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.3.2 </span> Maintain External Services",
                                    "href":"maintain-external-services.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.3.3 </span> Maintain Upload Source Code",
                                    "href":"maintain-upload-source-code.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Integration of Oracle Banking Payments",
                    "href":"integration-oracle-banking-payments.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">2.1 </span> Maintenance for Oracle Banking Branch",
                            "href":"maintenance-oracle-banking-branch1.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">2.1.1 </span> Create Entity",
                                    "href":"create-entity.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">2.2 </span> Maintenance for Oracle Banking Payments",
                            "href":"maintenance-oracle-banking-payments.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">2.2.1 </span> Maintain Source Details and Source Network Preferences",
                                    "href":"maintain-source-details-source-network-preferences.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">2.2.2 </span> Maintain External Notification and Queue Connection Profile",
                                    "href":"maintain-external-notification-queue-connection-profile.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Integration of Oracle Banking Virtual Account Management",
                    "href":"integration-oracle-banking-virtual-account-management.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">3.1 </span> Configurations for Oracle Banking Branch",
                            "href":"configurations-oracle-banking-branch.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.2 </span> Maintenance for Oracle Banking Virtual Account Management",
                            "href":"maintenance-oracle-banking-virtual-account-management.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">3.2.1 </span> Maintain Entry in Common Core",
                                    "href":"maintain-entry-common-core.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">3.2.2 </span> Create User and Assign Role",
                                    "href":"create-user-assign-role.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">3.2.3 </span> Create Upload Source",
                                    "href":"create-upload-source1.html"
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ]
});
